@@ -1,7 +1,7 @@
 package BioX::Workflow;
 
 use 5.008_005;
-our $VERSION = '0.10';
+our $VERSION = '0.12';
 
 use Moose;
 use File::Find::Rule;
@@ -331,7 +331,7 @@ template. Make sure to use the previously defined $OUT. For more information see
     rules:
         - backup:
             outdir: {$self->ROOT}/datafiles
-            override: 1
+            override_process: 1
             process: |
                 $OUT .= wget {$self->some_globally_defined_parameter}
                 {
@@ -598,17 +598,21 @@ has 'wait' => (
 =head3 override_process
 
 local:
-    - override: 1
+    - override_process: 1
 
 =cut
 
 has 'override_process' => (
-     is => 'rw',
-     isa => 'Bool',
-     default => 0,
-     predicate => 'has_override_proccess',
-     clearer => 'clear_override_proccess',
-     documentation => q(Instead of for my $sample (@sample){ DO STUFF } just DOSTUFF),
+    traits  => ['Bool'],
+    is => 'rw',
+    isa => 'Bool',
+    default => 0,
+    predicate => 'has_override_process',
+    documentation => q(Instead of for my $sample (@sample){ DO STUFF } just DOSTUFF),
+    handles => {
+        set_override_process => 'set',
+        clear_override_process => 'unset',
+    },
 );
 
 =head3 indir outdir
@@ -1127,13 +1131,14 @@ sub dothings {
         $self->make_outdir() unless $self->by_sample_outdir;
     }
 
-    if (exists $self->local_rule->{$key}->{override} && $self->local_rule->{$key}->{override} == 1){
+    if (exists $self->local_rule->{$key}->{override_process} && $self->local_rule->{$key}->{override_process} == 1){
         $self->override_process(1);
     }
 
     if(exists $self->local_rule->{$key}->{local}){
         $self->local_attr(Data::Pairs->new($self->local_rule->{$key}->{local}));
-        $self->attr($self->local_attr);
+        $self->add_attr;
+        #$self->attr($self->local_attr);
         $self->create_attr;
     }
 
@@ -1195,6 +1200,21 @@ sub dothings {
     }
 }
 
+=head2 add_attr
+
+Add the local attr onto the global attr
+
+=cut
+
+sub add_attr{
+    my $self = shift;
+    my @keys = $self->local_attr->get_keys();
+
+    foreach my $key (@keys){
+        $self->attr->add($key => $self->local_attr->get_values($key));
+    }
+}
+
 =head2 write_rule_meta
 
 =cut
